==> telepathy-qt4_0.5.6.orig.tar.gz: telepathy-qt4-0.5.6/TelepathyQt4/connection-internal.h <==
/*
 * This file is part of TelepathyQt4
 *
 * Copyright (C) 2008 Collabora Ltd. <http://www.collabora.co.uk/>
 * Copyright (C) 2008 Nokia Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _TelepathyQt4_connection_internal_h_HEADER_GUARD_
#define _TelepathyQt4_connection_internal_h_HEADER_GUARD_

#include <TelepathyQt4/Connection>

#include <TelepathyQt4/PendingReady>

#include <QSet>

namespace Tp
{

class TELEPATHY_QT4_NO_EXPORT Connection::PendingConnect : public PendingReady
{
    Q_OBJECT

public:
    PendingConnect(const ConnectionPtr &connection, const Features &requestedFeatures);

private Q_SLOTS:
    void onConnectReply(QDBusPendingCallWatcher *);
    void onStatusChanged(Tp::ConnectionStatus newStatus);
    void onBecomeReadyReply(Tp::PendingOperation *);
    void onConnInvalidated(Tp::DBusProxy *proxy, const QString &error, const QString &message);

private:
    friend class ConnectionLowlevel;
};

class ConnectionHelper
{
public:
    static QString statusReasonToErrorName(Tp::ConnectionStatusReason reason,
        Tp::ConnectionStatus oldStatus);
};

} // Tp

#endif

==> telepathy-qt4_0.5.12.orig.tar.gz: telepathy-qt4-0.5.12/TelepathyQt4/connection-internal.h <==
/**
 * This file is part of TelepathyQt4
 *
 * @copyright Copyright (C) 2008 Collabora Ltd. <http://www.collabora.co.uk/>
 * @copyright Copyright (C) 2008 Nokia Corporation
 * @license LGPL 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _TelepathyQt4_connection_internal_h_HEADER_GUARD_
#define _TelepathyQt4_connection_internal_h_HEADER_GUARD_

#include <TelepathyQt4/Connection>

#include <TelepathyQt4/PendingReady>

#include <QSet>

namespace Tp
{

class TELEPATHY_QT4_NO_EXPORT Connection::PendingConnect : public PendingReady
{
    Q_OBJECT

public:
    PendingConnect(const ConnectionPtr &connection, const Features &requestedFeatures);

private Q_SLOTS:
    TELEPATHY_QT4_NO_EXPORT void onConnectReply(QDBusPendingCallWatcher *);
    TELEPATHY_QT4_NO_EXPORT void onStatusChanged(Tp::ConnectionStatus newStatus);
    TELEPATHY_QT4_NO_EXPORT void onBecomeReadyReply(Tp::PendingOperation *);
    TELEPATHY_QT4_NO_EXPORT void onConnInvalidated(Tp::DBusProxy *proxy, const QString &error, const QString &message);

private:
    friend class ConnectionLowlevel;
};

class ConnectionHelper
{
public:
    static QString statusReasonToErrorName(Tp::ConnectionStatusReason reason,
        Tp::ConnectionStatus oldStatus);
};

} // Tp

#endif
